import { GraphQLResolveInfo } from 'graphql';
import * as Apollo from '@apollo/client';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
};
export declare type ClientCounter = {
    __typename?: 'ClientCounter';
    counter?: Maybe<Scalars['Int']>;
};
/**  Database counter  */
export declare type Counter = {
    __typename?: 'Counter';
    /**  Current amount  */
    amount: Scalars['Int'];
};
export declare type Mutation = {
    __typename?: 'Mutation';
    /**  Increase counter value returns current counter amount  */
    addCounter?: Maybe<Counter>;
    addCounterState?: Maybe<ClientCounter>;
    /**  add Counter  */
    addMoleculerCounter?: Maybe<Counter>;
    /**  sync cached counter with current value  */
    syncCachedCounter?: Maybe<Scalars['Boolean']>;
};
export declare type MutationAddCounterArgs = {
    amount?: Maybe<Scalars['Int']>;
};
export declare type MutationAddCounterStateArgs = {
    amount: Scalars['Int'];
};
export declare type MutationAddMoleculerCounterArgs = {
    amount?: Maybe<Scalars['Int']>;
};
export declare type Query = {
    __typename?: 'Query';
    /**  Counter  */
    counter?: Maybe<Counter>;
    /**  Counter from Datasource  */
    counterCache?: Maybe<Counter>;
    counterState?: Maybe<ClientCounter>;
    /**  Moleculer Counter  */
    moleculerCounter?: Maybe<Counter>;
};
export declare type Subscription = {
    __typename?: 'Subscription';
    /**  Subscription fired when anyone increases counter  */
    counterUpdated?: Maybe<Counter>;
    moleculerCounterUpdate?: Maybe<Counter>;
};
export declare type AddCounterStateMutationVariables = Exact<{
    amount: Scalars['Int'];
}>;
export declare type AddCounterStateMutation = ({
    __typename?: 'Mutation';
} & {
    addCounterState?: Maybe<({
        __typename?: 'ClientCounter';
    } & Pick<ClientCounter, 'counter'>)>;
});
export declare type AddCounterMutationVariables = Exact<{
    amount: Scalars['Int'];
}>;
export declare type AddCounterMutation = ({
    __typename?: 'Mutation';
} & {
    addCounter?: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type AddCounter_WsMutationVariables = Exact<{
    amount: Scalars['Int'];
}>;
export declare type AddCounter_WsMutation = ({
    __typename?: 'Mutation';
} & {
    addCounter?: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type SyncCachedCounterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type SyncCachedCounterMutation = ({
    __typename?: 'Mutation';
} & Pick<Mutation, 'syncCachedCounter'>);
export declare type CounterCacheQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type CounterCacheQueryQuery = ({
    __typename?: 'Query';
} & {
    counterCache?: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type CounterStateQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type CounterStateQuery = ({
    __typename?: 'Query';
} & {
    counterState?: Maybe<({
        __typename?: 'ClientCounter';
    } & Pick<ClientCounter, 'counter'>)>;
});
export declare type CounterQueryQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type CounterQueryQuery = ({
    __typename?: 'Query';
} & {
    counter?: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type OnCounterUpdatedSubscriptionVariables = Exact<{
    [key: string]: never;
}>;
export declare type OnCounterUpdatedSubscription = ({
    __typename?: 'Subscription';
} & {
    counterUpdated?: Maybe<({
        __typename?: 'Counter';
    } & Pick<Counter, 'amount'>)>;
});
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type ResolversTypes = {
    Query: ResolverTypeWrapper<{}>;
    Counter: ResolverTypeWrapper<Counter>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    ClientCounter: ResolverTypeWrapper<ClientCounter>;
    Mutation: ResolverTypeWrapper<{}>;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
    Subscription: ResolverTypeWrapper<{}>;
    String: ResolverTypeWrapper<Scalars['String']>;
};
/** Mapping between all available schema types and the resolvers parents */
export declare type ResolversParentTypes = {
    Query: {};
    Counter: Counter;
    Int: Scalars['Int'];
    ClientCounter: ClientCounter;
    Mutation: {};
    Boolean: Scalars['Boolean'];
    Subscription: {};
    String: Scalars['String'];
};
export declare type ClientCounterResolvers<ContextType = any, ParentType extends ResolversParentTypes['ClientCounter'] = ResolversParentTypes['ClientCounter']> = {
    counter?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type CounterResolvers<ContextType = any, ParentType extends ResolversParentTypes['Counter'] = ResolversParentTypes['Counter']> = {
    amount?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type MutationResolvers<ContextType = any, ParentType extends ResolversParentTypes['Mutation'] = ResolversParentTypes['Mutation']> = {
    addCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType, RequireFields<MutationAddCounterArgs, never>>;
    addCounterState?: Resolver<Maybe<ResolversTypes['ClientCounter']>, ParentType, ContextType, RequireFields<MutationAddCounterStateArgs, 'amount'>>;
    addMoleculerCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType, RequireFields<MutationAddMoleculerCounterArgs, never>>;
    syncCachedCounter?: Resolver<Maybe<ResolversTypes['Boolean']>, ParentType, ContextType>;
};
export declare type QueryResolvers<ContextType = any, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = {
    counter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
    counterCache?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
    counterState?: Resolver<Maybe<ResolversTypes['ClientCounter']>, ParentType, ContextType>;
    moleculerCounter?: Resolver<Maybe<ResolversTypes['Counter']>, ParentType, ContextType>;
};
export declare type SubscriptionResolvers<ContextType = any, ParentType extends ResolversParentTypes['Subscription'] = ResolversParentTypes['Subscription']> = {
    counterUpdated?: SubscriptionResolver<Maybe<ResolversTypes['Counter']>, "counterUpdated", ParentType, ContextType>;
    moleculerCounterUpdate?: SubscriptionResolver<Maybe<ResolversTypes['Counter']>, "moleculerCounterUpdate", ParentType, ContextType>;
};
export declare type Resolvers<ContextType = any> = {
    ClientCounter?: ClientCounterResolvers<ContextType>;
    Counter?: CounterResolvers<ContextType>;
    Mutation?: MutationResolvers<ContextType>;
    Query?: QueryResolvers<ContextType>;
    Subscription?: SubscriptionResolvers<ContextType>;
};
/**
 * @deprecated
 * Use "Resolvers" root object instead. If you wish to get "IResolvers", add "typesPrefix: I" to your config.
 */
export declare type IResolvers<ContextType = any> = Resolvers<ContextType>;
export declare const AddCounterStateDocument: Apollo.DocumentNode;
/**
 * __useAddCounterStateMutation__
 *
 * To run a mutation, you first call `useAddCounterStateMutation` within a React component and pass it any options that fit your needs.
 * When your component renders, `useAddCounterStateMutation` returns a tuple that includes:
 * - A mutate function that you can call at any time to execute the mutation
 * - An object with fields that represent the current status of the mutation's execution
 *
 * @param baseOptions options that will be passed into the mutation, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options-2;
 *
 * @example
 * const [addCounterStateMutation, { data, loading, error }] = useAddCounterStateMutation({
 *   variables: {
 *      amount: // value for 'amount'
 *   },
 * });
 */
export declare function useAddCounterStateMutation(baseOptions?: Apollo.MutationHookOptions<AddCounterStateMutation, AddCounterStateMutationVariables>): Apollo.MutationTuple<AddCounterStateMutation, Exact<{
    amount: number;
}>, Apollo.DefaultContext, Apollo.ApolloCache<any>>;
export declare type AddCounterStateMutationHookResult = ReturnType<typeof useAddCounterStateMutation>;
export declare type AddCounterStateMutationResult = Apollo.MutationResult<AddCounterStateMutation>;
export declare type AddCounterStateMutationOptions = Apollo.BaseMutationOptions<AddCounterStateMutation, AddCounterStateMutationVariables>;
export declare const AddCounterDocument: Apollo.DocumentNode;
/**
 * __useAddCounterMutation__
 *
 * To run a mutation, you first call `useAddCounterMutation` within a React component and pass it any options that fit your needs.
 * When your component renders, `useAddCounterMutation` returns a tuple that includes:
 * - A mutate function that you can call at any time to execute the mutation
 * - An object with fields that represent the current status of the mutation's execution
 *
 * @param baseOptions options that will be passed into the mutation, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options-2;
 *
 * @example
 * const [addCounterMutation, { data, loading, error }] = useAddCounterMutation({
 *   variables: {
 *      amount: // value for 'amount'
 *   },
 * });
 */
export declare function useAddCounterMutation(baseOptions?: Apollo.MutationHookOptions<AddCounterMutation, AddCounterMutationVariables>): Apollo.MutationTuple<AddCounterMutation, Exact<{
    amount: number;
}>, Apollo.DefaultContext, Apollo.ApolloCache<any>>;
export declare type AddCounterMutationHookResult = ReturnType<typeof useAddCounterMutation>;
export declare type AddCounterMutationResult = Apollo.MutationResult<AddCounterMutation>;
export declare type AddCounterMutationOptions = Apollo.BaseMutationOptions<AddCounterMutation, AddCounterMutationVariables>;
export declare const AddCounter_WsDocument: Apollo.DocumentNode;
/**
 * __useAddCounter_WsMutation__
 *
 * To run a mutation, you first call `useAddCounter_WsMutation` within a React component and pass it any options that fit your needs.
 * When your component renders, `useAddCounter_WsMutation` returns a tuple that includes:
 * - A mutate function that you can call at any time to execute the mutation
 * - An object with fields that represent the current status of the mutation's execution
 *
 * @param baseOptions options that will be passed into the mutation, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options-2;
 *
 * @example
 * const [addCounterWsMutation, { data, loading, error }] = useAddCounter_WsMutation({
 *   variables: {
 *      amount: // value for 'amount'
 *   },
 * });
 */
export declare function useAddCounter_WsMutation(baseOptions?: Apollo.MutationHookOptions<AddCounter_WsMutation, AddCounter_WsMutationVariables>): Apollo.MutationTuple<AddCounter_WsMutation, Exact<{
    amount: number;
}>, Apollo.DefaultContext, Apollo.ApolloCache<any>>;
export declare type AddCounter_WsMutationHookResult = ReturnType<typeof useAddCounter_WsMutation>;
export declare type AddCounter_WsMutationResult = Apollo.MutationResult<AddCounter_WsMutation>;
export declare type AddCounter_WsMutationOptions = Apollo.BaseMutationOptions<AddCounter_WsMutation, AddCounter_WsMutationVariables>;
export declare const SyncCachedCounterDocument: Apollo.DocumentNode;
/**
 * __useSyncCachedCounterMutation__
 *
 * To run a mutation, you first call `useSyncCachedCounterMutation` within a React component and pass it any options that fit your needs.
 * When your component renders, `useSyncCachedCounterMutation` returns a tuple that includes:
 * - A mutate function that you can call at any time to execute the mutation
 * - An object with fields that represent the current status of the mutation's execution
 *
 * @param baseOptions options that will be passed into the mutation, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options-2;
 *
 * @example
 * const [syncCachedCounterMutation, { data, loading, error }] = useSyncCachedCounterMutation({
 *   variables: {
 *   },
 * });
 */
export declare function useSyncCachedCounterMutation(baseOptions?: Apollo.MutationHookOptions<SyncCachedCounterMutation, SyncCachedCounterMutationVariables>): Apollo.MutationTuple<SyncCachedCounterMutation, Exact<{
    [key: string]: never;
}>, Apollo.DefaultContext, Apollo.ApolloCache<any>>;
export declare type SyncCachedCounterMutationHookResult = ReturnType<typeof useSyncCachedCounterMutation>;
export declare type SyncCachedCounterMutationResult = Apollo.MutationResult<SyncCachedCounterMutation>;
export declare type SyncCachedCounterMutationOptions = Apollo.BaseMutationOptions<SyncCachedCounterMutation, SyncCachedCounterMutationVariables>;
export declare const CounterCacheQueryDocument: Apollo.DocumentNode;
/**
 * __useCounterCacheQueryQuery__
 *
 * To run a query within a React component, call `useCounterCacheQueryQuery` and pass it any options that fit your needs.
 * When your component renders, `useCounterCacheQueryQuery` returns an object from Apollo Client that contains loading, error, and data properties
 * you can use to render your UI.
 *
 * @param baseOptions options that will be passed into the query, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options;
 *
 * @example
 * const { data, loading, error } = useCounterCacheQueryQuery({
 *   variables: {
 *   },
 * });
 */
export declare function useCounterCacheQueryQuery(baseOptions?: Apollo.QueryHookOptions<CounterCacheQueryQuery, CounterCacheQueryQueryVariables>): Apollo.QueryResult<CounterCacheQueryQuery, Exact<{
    [key: string]: never;
}>>;
export declare function useCounterCacheQueryLazyQuery(baseOptions?: Apollo.LazyQueryHookOptions<CounterCacheQueryQuery, CounterCacheQueryQueryVariables>): Apollo.LazyQueryResultTuple<CounterCacheQueryQuery, Exact<{
    [key: string]: never;
}>>;
export declare type CounterCacheQueryQueryHookResult = ReturnType<typeof useCounterCacheQueryQuery>;
export declare type CounterCacheQueryLazyQueryHookResult = ReturnType<typeof useCounterCacheQueryLazyQuery>;
export declare type CounterCacheQueryQueryResult = Apollo.QueryResult<CounterCacheQueryQuery, CounterCacheQueryQueryVariables>;
export declare const CounterStateDocument: Apollo.DocumentNode;
/**
 * __useCounterStateQuery__
 *
 * To run a query within a React component, call `useCounterStateQuery` and pass it any options that fit your needs.
 * When your component renders, `useCounterStateQuery` returns an object from Apollo Client that contains loading, error, and data properties
 * you can use to render your UI.
 *
 * @param baseOptions options that will be passed into the query, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options;
 *
 * @example
 * const { data, loading, error } = useCounterStateQuery({
 *   variables: {
 *   },
 * });
 */
export declare function useCounterStateQuery(baseOptions?: Apollo.QueryHookOptions<CounterStateQuery, CounterStateQueryVariables>): Apollo.QueryResult<CounterStateQuery, Exact<{
    [key: string]: never;
}>>;
export declare function useCounterStateLazyQuery(baseOptions?: Apollo.LazyQueryHookOptions<CounterStateQuery, CounterStateQueryVariables>): Apollo.LazyQueryResultTuple<CounterStateQuery, Exact<{
    [key: string]: never;
}>>;
export declare type CounterStateQueryHookResult = ReturnType<typeof useCounterStateQuery>;
export declare type CounterStateLazyQueryHookResult = ReturnType<typeof useCounterStateLazyQuery>;
export declare type CounterStateQueryResult = Apollo.QueryResult<CounterStateQuery, CounterStateQueryVariables>;
export declare const CounterQueryDocument: Apollo.DocumentNode;
/**
 * __useCounterQueryQuery__
 *
 * To run a query within a React component, call `useCounterQueryQuery` and pass it any options that fit your needs.
 * When your component renders, `useCounterQueryQuery` returns an object from Apollo Client that contains loading, error, and data properties
 * you can use to render your UI.
 *
 * @param baseOptions options that will be passed into the query, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options;
 *
 * @example
 * const { data, loading, error } = useCounterQueryQuery({
 *   variables: {
 *   },
 * });
 */
export declare function useCounterQueryQuery(baseOptions?: Apollo.QueryHookOptions<CounterQueryQuery, CounterQueryQueryVariables>): Apollo.QueryResult<CounterQueryQuery, Exact<{
    [key: string]: never;
}>>;
export declare function useCounterQueryLazyQuery(baseOptions?: Apollo.LazyQueryHookOptions<CounterQueryQuery, CounterQueryQueryVariables>): Apollo.LazyQueryResultTuple<CounterQueryQuery, Exact<{
    [key: string]: never;
}>>;
export declare type CounterQueryQueryHookResult = ReturnType<typeof useCounterQueryQuery>;
export declare type CounterQueryLazyQueryHookResult = ReturnType<typeof useCounterQueryLazyQuery>;
export declare type CounterQueryQueryResult = Apollo.QueryResult<CounterQueryQuery, CounterQueryQueryVariables>;
export declare const OnCounterUpdatedDocument: Apollo.DocumentNode;
/**
 * __useOnCounterUpdatedSubscription__
 *
 * To run a query within a React component, call `useOnCounterUpdatedSubscription` and pass it any options that fit your needs.
 * When your component renders, `useOnCounterUpdatedSubscription` returns an object from Apollo Client that contains loading, error, and data properties
 * you can use to render your UI.
 *
 * @param baseOptions options that will be passed into the subscription, supported options are listed on: https://www.apollographql.com/docs/react/api/react-hooks/#options;
 *
 * @example
 * const { data, loading, error } = useOnCounterUpdatedSubscription({
 *   variables: {
 *   },
 * });
 */
export declare function useOnCounterUpdatedSubscription(baseOptions?: Apollo.SubscriptionHookOptions<OnCounterUpdatedSubscription, OnCounterUpdatedSubscriptionVariables>): Apollo.SubscriptionResult<OnCounterUpdatedSubscription, any>;
export declare type OnCounterUpdatedSubscriptionHookResult = ReturnType<typeof useOnCounterUpdatedSubscription>;
export declare type OnCounterUpdatedSubscriptionResult = Apollo.SubscriptionResult<OnCounterUpdatedSubscription>;
//# sourceMappingURL=generated-models.d.ts.map